@@ -1262,7 +1262,7 @@ class NapariSTPT:
             #hbox.addStretch(1)
 
             hbox.addWidget(QtWidgets.QLabel("Output pixel size:"))
-            self.pixel_size = QtWidgets.QLineEdit("7.5")
+            self.pixel_size = QtWidgets.QLineEdit("15")
             self.pixel_size.setMaximumWidth(50)
             hbox.addWidget(self.pixel_size)
             hbox.addStretch(1)
